@@ -1,6 +1,6 @@
 /*
  *    HardInfo - Displays System Information
- *    Copyright (C) 2003-2006 Leandro A. F. Pereira <leandro@linuxmag.com.br>
+ *    Copyright (C) 2003-2007 Leandro A. F. Pereira <leandro@linuxmag.com.br>
  *
  *    This program is free software; you can redistribute it and/or modify
  *    it under the terms of the GNU General Public License as published by
@@ -19,11 +19,21 @@
 #ifndef __CALLBACKS_H__
 #define __CALLBACKS_H__
 
+#include <gtk/gtk.h>
+
 void cb_about();
+void cb_about_module(GtkAction *action);
 void cb_generate_report();
+void cb_save_graphic();
 void cb_quit();
 void cb_refresh();
+void cb_copy_to_clipboard();
 void cb_side_pane();
 void cb_toolbar();
+void cb_open_web_page();
+void cb_open_online_docs();
+void cb_sync_manager();
+void cb_report_bug();
+void cb_donate();
 
 #endif	/* __CALLBACKS_H__ */
