@@ -1,6 +1,6 @@
 /*
  *    HardInfo - Displays System Information
- *    Copyright (C) 2003-2006 Leandro A. F. Pereira <leandro@linuxmag.com.br>
+ *    Copyright (C) 2003-2007 Leandro A. F. Pereira <leandro@linuxmag.com.br>
  *
  *    This program is free software; you can redistribute it and/or modify
  *    it under the terms of the GNU General Public License as published by
@@ -20,6 +20,11 @@
 #define __STOCK_H__
 
 #define HI_STOCK_REPORT		"hi-stock-report"
+#define HI_STOCK_INTERNET	"hi-stock-internet"
+#define HI_STOCK_MODULE		"hi-stock-module"
+#define HI_STOCK_ABOUT_MODULES	"hi-stock-about-modules"
+#define HI_STOCK_SYNC_MENU	"hi-stock-sync-menu"
+#define HI_STOCK_DONATE		"hi-stock-donate"
 
 void stock_icons_init(void);
 void stock_icon_register(gchar *filename, gchar *stock_id);
